@@ -6,45 +6,20 @@
  * @ref License
  */
 
-/* LICENSE
- *
- * Copyright (c) 2008-2019 OpenShot Studios, LLC
- * <http://www.openshotstudios.com/>. This file is part of
- * OpenShot Library (libopenshot), an open-source project dedicated to
- * delivering high quality video editing and animation solutions to the
- * world. For more information visit <http://www.openshot.org/>.
- *
- * OpenShot Library (libopenshot) is free software: you can redistribute it
- * and/or modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * OpenShot Library (libopenshot) is distributed in the hope that it will be
- * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with OpenShot Library. If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (c) 2008-2019 OpenShot Studios, LLC
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #ifndef OPENSHOT_LOGGER_H
 #define OPENSHOT_LOGGER_H
 
 
-#include <iostream>
-#include <iomanip>
 #include <fstream>
-#include <cstdlib>
+#include <memory>
+#include <mutex>
 #include <string>
-#include <sstream>
-#include <cstdio>
-#include <ctime>
-#include <zmq.hpp>
-#include <unistd.h>
-#include <OpenShotAudio.h>
-#include "Settings.h"
 
+#include <zmq.hpp>
 
 namespace openshot {
 
@@ -56,7 +31,7 @@ namespace openshot {
 	 */
 	class ZmqLogger {
 	private:
-		juce::CriticalSection loggerCriticalSection;
+		std::recursive_mutex loggerMutex;
 		std::string connection;
 
 		// Logfile related vars
